@@ -1,8 +1,14 @@
 jQuery(document).ready(function($){
   $('notices_primary').infinitescroll({
-    debug: true,
+    debug: false,
     infiniteScroll  : false,
-    nextSelector    : "li.nav_next a",
+    nextSelector    : 'body#public li.nav_next a,'+
+                      'body#all li.nav_next a,'+
+                      'body#showstream li.nav_next a,'+
+                      'body#replies li.nav_next a,'+
+                      'body#showfavorites li.nav_next a,'+
+                      'body#showgroup li.nav_next a,'+
+                      'body#favorited li.nav_next a',
     loadingImg      : $('address .url')[0].href+'plugins/InfiniteScroll/ajax-loader.gif',
     text            : "<em>Loading the next set of posts...</em>",
     donetext        : "<em>Congratulations, you\'ve reached the end of the Internet.</em>",
@@ -11,5 +17,7 @@ jQuery(document).ready(function($){
     itemSelector    : "#notices_primary ol.notices li"
     },function(){
         NoticeAttachments();
+        NoticeReply();
+        NoticeFavors();
     });
 });
